**Example 1: 获取专业版信息**

获取专业版信息

Input: 

```
tccli yunjing DescribeProVersionInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "354f4ac3-8546-4516-8c8a-69e3ab73aa8a",
        "PostPayCost": 4,
        "IsAutoOpenProVersion": false,
        "ProVersionNum": 10
    }
}
```

